summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmblobcylinderedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmblobcylinderedit.h')
-rw-r--r--kpovmodeler/pmblobcylinderedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmblobcylinderedit.h b/kpovmodeler/pmblobcylinderedit.h
index dbe24134..103d5a4f 100644
--- a/kpovmodeler/pmblobcylinderedit.h
+++ b/kpovmodeler/pmblobcylinderedit.h
@@ -37,9 +37,9 @@ class PMBlobCylinderEdit : public PMDetailObjectEdit
typedef PMDetailObjectEdit Base;
public:
/**
* Creates a PMBlobCylinderEdit with tqparent and name
*/
- PMBlobCylinderEdit( TQWidget* tqparent, const char* name = 0 );
+ PMBlobCylinderEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -37,9 +37,9 @@ class PMBlobCylinderEdit : public PMDetailObjectEdit
public:
/**
- * Creates a PMBlobCylinderEdit with tqparent and name
+ * Creates a PMBlobCylinderEdit with parent and name
*/